# -*- coding: utf-8 -*-

SAMPLES = [
    {'url': 'http://ppomppu.co.kr/',
     'encoding': 'euc-kr',
     'contains': '장터 리스트'},

    {'url': 'http://www.interpark.com/malls/index.html',
     'encoding': 'euc-kr',
     'contains': '유아동'},

    {'url': 'http://chosun.com/',
     'encoding': 'euc-kr',
     'contains': '사내칼럼'},

    {'url': 'https://www.momoshop.com.tw/main/Main.jsp',
     'encoding': 'MS950',
     'contains': '鞋展獨降'},

    {'url': 'http://www.rakuten.co.jp/',
     'encoding': 'EUC-JP',
     'contains': '送料無料の商品を探す'},

    {'url': 'http://www.qq.com/',
     'encoding': 'GB2312',
     'contains': '今日话题'},

    {'url': 'http://www.kooora.com/',
     'encoding': 'windows-1256',
     'contains': 'أبطال أوروبا'},

    {'url': 'http://www.alwasatnews.com/',
     'encoding': None,
     'contains': 'أوقات الصلاة'},

    {'url': 'https://pantip.com/',
     'encoding': None,
     'contains': 'หน้าแรก'},

    {'url': 'http://manager.co.th/home/',
     'encoding': None,
     'contains': 'ขายสบู่ถูจิ๊มิ๊'},

    {'url': 'http://www.telewebion.com/#!/',
     'encoding': None,
     'contains': 'خروج از سیستم'},

    {'url': 'http://www.varzesh3.com/',
     'encoding': None,
     'contains': 'اخبار فوتبال و والیبال'}
]

